<?php
declare(strict_types=1);

namespace FiloBlu\Refilo\Helper\Catalog;

use Magento\Catalog\Api\Data\CategoryInterface;
use Magento\Catalog\Model\Category;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\ScopeInterface;

/**
 *
 */
class CategoryHelper
{
    public const XML_REFILO_SEARCH_GENERAL_USE_CATEGORY_FULL_PATH_ = 'refilo_search/general/use_category_full_path';

    public const XML_REFILO_SEARCH_GENERAL_CATEGORY_FULL_PATH_SEPARATOR = 'refilo_search/general/category_full_path_separator';
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(ScopeConfigInterface $scopeConfig)
    {
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param CategoryInterface| Category $category
     */
    public function getFullName($category)
    {
        $useFullName = $this->scopeConfig->isSetFlag
        (
            self::XML_REFILO_SEARCH_GENERAL_USE_CATEGORY_FULL_PATH_,
            ScopeInterface::SCOPE_STORE,
            $category->getStore()
        );


        if (!$useFullName) {
            return $category->getName();
        }

        $names = [$category->getName()];


        $parent = $category->getParentCategory();

        while(true)
        {
            if((int)$parent->getLevel() <= 1 || !$parent->getParentId()) {
                break;
            }

            array_unshift($names, $parent->getName());

            $parent = $parent->getParentCategory();
        }

        $separator = $this->scopeConfig->getValue
        (
            self::XML_REFILO_SEARCH_GENERAL_CATEGORY_FULL_PATH_SEPARATOR,
            ScopeInterface::SCOPE_STORE,
            $category->getStore()
        ) ?? ' / ';
        return implode($separator, $names);

    }
}
